==> qtjambi-dbus-debuginfo-macos-6.6.1.jar: sources/QtJambiDBus/QDBusSignature_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusSignature(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusSignature")
    QDBusSignature *_ptr = reinterpret_cast<QDBusSignature *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusSignature()
void __qt_construct_QDBusSignature_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature()")
    Q_UNUSED(__java_arguments)
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QDBusSignature(QString&&)
void __qt_construct_QDBusSignature_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature(QString&&)")
    jobject sig0 = __java_arguments[0].l;
    QString& __qt_sig0 = qtjambi_cast<QString& >(__jni_env, sig0);
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature(std::move(__qt_sig0));
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QDBusSignature(QString)
void __qt_construct_QDBusSignature_2(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature(QString)")
    jstring signature0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_signature0 = qtjambi_cast<QString>(__jni_env, signature0);
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature(__qt_signature0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QDBusSignature
void __qt_destruct_QDBusSignature(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusSignature")
    reinterpret_cast<QDBusSignature*>(ptr)->~QDBusSignature();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusSignature::QDBusSignature()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_0, sizeof(QDBusSignature), typeid(QDBusSignature), false, &deleter_QDBusSignature, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusSignature::QDBusSignature(QString&&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2Ljava_lang_CharSequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject sig0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature(QString&&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = sig0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_1, sizeof(QDBusSignature), typeid(QDBusSignature), false, &deleter_QDBusSignature, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusSignature::QDBusSignature(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring signature0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = signature0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_2, sizeof(QDBusSignature), typeid(QDBusSignature), false, &deleter_QDBusSignature, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusSignature::operator<(QDBusSignature,QDBusSignature)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_operator_1less_1native_1cref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::operator<(QDBusSignature,QDBusSignature)", __qt_this)
        const QDBusSignature& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusSignature>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::operator==(QDBusSignature,QDBusSignature)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_equals_1native_1cref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::operator==(QDBusSignature,QDBusSignature)", __qt_this)
        const QDBusSignature& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusSignature>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::setSignature(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_setSignature_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring signature0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::setSignature(QString)", __qt_this)
        QString  __qt_signature0 = qtjambi_cast<QString>(__jni_env, signature0);
        __qt_this->setSignature(__qt_signature0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusSignature::signature()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_signature_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::signature()const", __qt_this)
        QString __qt_return_value = __qt_this->signature();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::swap(QDBusSignature&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_swap_1native_1ref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::swap(QDBusSignature&)", __qt_this)
        QDBusSignature& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusSignature>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusSignature(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusSignature>("QDBusSignature", "io/qt/dbus/QDBusSignature");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDBusSignature, {
        ConstructorInfo(&__qt_construct_QDBusSignature_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusSignature_1, "Lio/qt/core/QString;")
       ,ConstructorInfo(&__qt_construct_QDBusSignature_2, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusSignature);
    registerMetaType<QDBusSignature>("QDBusSignature");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-dbus-debuginfo-macos-6.7.1.jar: sources/QtJambiDBus/QDBusSignature_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtDBus/qdbusextratypes.h>
#include <QtCore/QVariant>
#include <QtCore/qstring.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDBusSignature(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDBusSignature")
    QDBusSignature *_ptr = reinterpret_cast<QDBusSignature *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDBusSignature()
void __qt_construct_QDBusSignature(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature()")
    Q_UNUSED(__java_arguments)
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDBusSignature::QDBusSignature()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature, sizeof(QDBusSignature), typeid(QDBusSignature), 0, false, &deleter_QDBusSignature, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusSignature(QDBusSignature)
void __qt_construct_QDBusSignature_cref_QDBusSignature(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature(QDBusSignature)")
    jobject other0 = __java_arguments[0].l;
    const QDBusSignature& __qt_other0 = qtjambi_cast<const QDBusSignature&>(__jni_env, other0);
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDBusSignature::QDBusSignature(QDBusSignature)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2Lio_qt_dbus_QDBusSignature_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature(QDBusSignature)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_cref_QDBusSignature, sizeof(QDBusSignature), typeid(QDBusSignature), 0, false, &deleter_QDBusSignature, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusSignature(QString&&)
void __qt_construct_QDBusSignature_rval_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature(QString&&)")
    jobject sig0 = __java_arguments[0].l;
    QString& __qt_sig0 = qtjambi_cast<QString&>(__jni_env, sig0);
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature(std::move(__qt_sig0));
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDBusSignature::QDBusSignature(QString&&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2Ljava_lang_CharSequence_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject sig0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature(QString&&)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = sig0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_rval_QString, sizeof(QDBusSignature), typeid(QDBusSignature), 0, false, &deleter_QDBusSignature, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDBusSignature(QString)
void __qt_construct_QDBusSignature_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDBusSignature(QString)")
    jstring signature0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_signature0 = qtjambi_cast<QString>(__jni_env, signature0);
    QDBusSignature *__qt_this = new(__qtjambi_ptr) QDBusSignature(__qt_signature0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDBusSignature::QDBusSignature(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_initialize_1native__Lio_qt_dbus_QDBusSignature_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring signature0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDBusSignature::QDBusSignature(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = signature0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDBusSignature_cref_QString, sizeof(QDBusSignature), typeid(QDBusSignature), 0, false, &deleter_QDBusSignature, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDBusSignature
void __qt_destruct_QDBusSignature(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDBusSignature")
    reinterpret_cast<QDBusSignature*>(ptr)->~QDBusSignature();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDBusSignature::operator<(QDBusSignature,QDBusSignature)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_operator_1less_1native_1cref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::operator<(QDBusSignature,QDBusSignature)", __this_nativeId)
        const QDBusSignature& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusSignature>(rhs1);
        __java_return_value = (*__qt_this) < __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::operator==(QDBusSignature,QDBusSignature)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_equals_1native_1cref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::operator==(QDBusSignature,QDBusSignature)", __this_nativeId)
        const QDBusSignature& __qt_rhs1 = QtJambiAPI::valueReferenceFromNativeId<QDBusSignature>(rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::setSignature(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_setSignature_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring signature0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::setSignature(QString)", __this_nativeId)
        QString  __qt_signature0 = qtjambi_cast<QString>(__jni_env, signature0);
        __qt_this->setSignature(__qt_signature0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDBusSignature::signature()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_signature_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::signature()const", __this_nativeId)
        QString __qt_return_value = __qt_this->signature();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDBusSignature::swap(QDBusSignature&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_swap_1native_1ref_1QDBusSignature__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDBusSignature::swap(QDBusSignature&)", __this_nativeId)
        QDBusSignature& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QDBusSignature>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_dbus_QDBusSignature_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDBusSignature *__qt_this = QtJambiAPI::objectFromNativeId<QDBusSignature>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDBusSignature(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDBusSignature>("QDBusSignature", "io/qt/dbus/QDBusSignature");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDBusSignature, {
        ConstructorInfo(&__qt_construct_QDBusSignature, nullptr)
       ,ConstructorInfo(&__qt_construct_QDBusSignature_cref_QDBusSignature, "Lio/qt/dbus/QDBusSignature;")
       ,ConstructorInfo(&__qt_construct_QDBusSignature_rval_QString, "Lio/qt/core/QString;")
       ,ConstructorInfo(&__qt_construct_QDBusSignature_cref_QString, "Ljava/lang/String;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDBusSignature);
    registerMetaType<QDBusSignature>("QDBusSignature");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
